@@ -22,11 +22,13 @@ setup(name='foo', version='0.1', py_modules=['foo'],
 
 """
 
-class BuildRpmTestCase(support.TempdirManager,
-                       support.EnvironGuard,
-                       support.LoggingSilencer,
-                       unittest.TestCase):
 
+class BuildRpmTestCase(
+    support.TempdirManager,
+    support.EnvironGuard,
+    support.LoggingSilencer,
+    unittest.TestCase,
+):
     def setUp(self):
         try:
             sys.executable.encode("UTF-8")
@@ -45,17 +47,18 @@ class BuildRpmTestCase(support.TempdirManager,
 
     # XXX I am unable yet to make this test work without
     # spurious sdtout/stderr output under Mac OS X
-    @unittest.skipUnless(sys.platform.startswith('linux'),
-                         'spurious sdtout/stderr output under Mac OS X')
+    @unittest.skipUnless(
+        sys.platform.startswith('linux'), 'spurious sdtout/stderr output under Mac OS X'
+    )
     @requires_zlib()
-    @unittest.skipIf(find_executable('rpm') is None,
-                     'the rpm command is not found')
-    @unittest.skipIf(find_executable('rpmbuild') is None,
-                     'the rpmbuild command is not found')
+    @unittest.skipIf(find_executable('rpm') is None, 'the rpm command is not found')
+    @unittest.skipIf(
+        find_executable('rpmbuild') is None, 'the rpmbuild command is not found'
+    )
     def test_quiet(self):
         # let's create a package
         tmp_dir = self.mkdtemp()
-        os.environ['HOME'] = tmp_dir   # to confine dir '.rpmdb' creation
+        os.environ['HOME'] = tmp_dir  # to confine dir '.rpmdb' creation
         pkg_dir = os.path.join(tmp_dir, 'foo')
         os.mkdir(pkg_dir)
         self.write_file((pkg_dir, 'setup.py'), SETUP_PY)
@@ -63,10 +66,16 @@ class BuildRpmTestCase(support.TempdirManager,
         self.write_file((pkg_dir, 'MANIFEST.in'), 'include foo.py')
         self.write_file((pkg_dir, 'README'), '')
 
-        dist = Distribution({'name': 'foo', 'version': '0.1',
-                             'py_modules': ['foo'],
-                             'url': 'xxx', 'author': 'xxx',
-                             'author_email': 'xxx'})
+        dist = Distribution(
+            {
+                'name': 'foo',
+                'version': '0.1',
+                'py_modules': ['foo'],
+                'url': 'xxx',
+                'author': 'xxx',
+                'author_email': 'xxx',
+            }
+        )
         dist.script_name = 'setup.py'
         os.chdir(pkg_dir)
 
@@ -84,22 +93,25 @@ class BuildRpmTestCase(support.TempdirManager,
 
         # bug #2945: upload ignores bdist_rpm files
         self.assertIn(('bdist_rpm', 'any', 'dist/foo-0.1-1.src.rpm'), dist.dist_files)
-        self.assertIn(('bdist_rpm', 'any', 'dist/foo-0.1-1.noarch.rpm'), dist.dist_files)
+        self.assertIn(
+            ('bdist_rpm', 'any', 'dist/foo-0.1-1.noarch.rpm'), dist.dist_files
+        )
 
     # XXX I am unable yet to make this test work without
     # spurious sdtout/stderr output under Mac OS X
-    @unittest.skipUnless(sys.platform.startswith('linux'),
-                         'spurious sdtout/stderr output under Mac OS X')
+    @unittest.skipUnless(
+        sys.platform.startswith('linux'), 'spurious sdtout/stderr output under Mac OS X'
+    )
     @requires_zlib()
     # http://bugs.python.org/issue1533164
-    @unittest.skipIf(find_executable('rpm') is None,
-                     'the rpm command is not found')
-    @unittest.skipIf(find_executable('rpmbuild') is None,
-                     'the rpmbuild command is not found')
+    @unittest.skipIf(find_executable('rpm') is None, 'the rpm command is not found')
+    @unittest.skipIf(
+        find_executable('rpmbuild') is None, 'the rpmbuild command is not found'
+    )
     def test_no_optimize_flag(self):
         # let's create a package that breaks bdist_rpm
         tmp_dir = self.mkdtemp()
-        os.environ['HOME'] = tmp_dir   # to confine dir '.rpmdb' creation
+        os.environ['HOME'] = tmp_dir  # to confine dir '.rpmdb' creation
         pkg_dir = os.path.join(tmp_dir, 'foo')
         os.mkdir(pkg_dir)
         self.write_file((pkg_dir, 'setup.py'), SETUP_PY)
@@ -107,10 +119,16 @@ class BuildRpmTestCase(support.TempdirManager,
         self.write_file((pkg_dir, 'MANIFEST.in'), 'include foo.py')
         self.write_file((pkg_dir, 'README'), '')
 
-        dist = Distribution({'name': 'foo', 'version': '0.1',
-                             'py_modules': ['foo'],
-                             'url': 'xxx', 'author': 'xxx',
-                             'author_email': 'xxx'})
+        dist = Distribution(
+            {
+                'name': 'foo',
+                'version': '0.1',
+                'py_modules': ['foo'],
+                'url': 'xxx',
+                'author': 'xxx',
+                'author_email': 'xxx',
+            }
+        )
         dist.script_name = 'setup.py'
         os.chdir(pkg_dir)
 
@@ -127,12 +145,16 @@ class BuildRpmTestCase(support.TempdirManager,
 
         # bug #2945: upload ignores bdist_rpm files
         self.assertIn(('bdist_rpm', 'any', 'dist/foo-0.1-1.src.rpm'), dist.dist_files)
-        self.assertIn(('bdist_rpm', 'any', 'dist/foo-0.1-1.noarch.rpm'), dist.dist_files)
+        self.assertIn(
+            ('bdist_rpm', 'any', 'dist/foo-0.1-1.noarch.rpm'), dist.dist_files
+        )
 
         os.remove(os.path.join(pkg_dir, 'dist', 'foo-0.1-1.noarch.rpm'))
 
+
 def test_suite():
     return unittest.TestLoader().loadTestsFromTestCase(BuildRpmTestCase)
 
+
 if __name__ == '__main__':
     run_unittest(test_suite())
